dnl
dnl COX308_PATH_NETCDF([ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]])
dnl tests for netCDF, and defines NETCDF_CFLAGS and NETCDF_LIBS
dnl

AC_DEFUN([COX308_PATH_NETCDF],
[
AC_ARG_WITH(netcdf-prefix,
  AC_HELP_STRING([--with-netcdf-prefix=DIR],
		 [prefix where netCDF is installed]))

if test "x$with_netcdf_prefix" = "xyes" ; then
  AC_MSG_ERROR([
*** directory must be specified for --with-netcdf-prefix])
fi


if test "${with_netcdf_prefix+set}" = set ; then
  case "$with_netcdf_prefix" in
    [[\\/]]* | ?:[[\\/]]*)
      # Absolute path; do nothing.
      ;;
    *)
      # Relative path.  Make it absolute.
      with_netcdf_prefix="`pwd`/$with_netcdf_prefix"
      ;;
  esac
  NETCDF_CFLAGS="-I$with_netcdf_prefix/include"
  NETCDF_LIBS="-L$with_netcdf_prefix/lib -lnetcdf"
else
  NETCDF_CFLAGS=""
  NETCDF_LIBS="-lnetcdf"
fi

saved_LIBS="$LIBS"
saved_CPPFLAGS=$CPPFLAGS

CPPFLAGS="$CPPFLAGS $NETCDF_CFLAGS"
AC_CHECK_HEADER(netcdf.h,,[no_netcdf=yes])

if test "x$no_netcdf" != "xyes" ; then
  LIBS="$LIBS $NETCDF_LIBS"
  AC_MSG_CHECKING([for netCDF libraries])
  AC_TRY_LINK([#include <netcdf.h>], [int ncid; nc_open("/tmp", NC_NOWRITE, &ncid)],
    [AC_MSG_RESULT(ok)], [AC_MSG_RESULT([failed]); no_netcdf=yes])
fi

CPPFLAGS="$saved_CPPFLAGS"
LIBS="$saved_LIBS"

if test "x$no_netcdf" = "xyes" ; then
  NETCDF_CFLAGS=""
  NETCDF_LIBS=""
fi

AC_SUBST(NETCDF_CFLAGS)
AC_SUBST(NETCDF_LIBS)

AS_IF([test "x$no_netcdf" = "xyes"],[$2],[$1])
])

dnl
dnl yet another handy macro
dnl

AC_DEFUN([COX308_ERR_NETCDF],
[
AC_MSG_ERROR([
******************************************************************************
**  cannot continue without netCDF (http://www.google.com/search?q=netCDF)  **
******************************************************************************])
])
